Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(403)

Unified Diff: net/log/write_to_file_net_log_observer.h

Issue 1084533002: Rename NetLogLogger and CapturingNetLog (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rename NetLogLogger and CapturingNetLog(removed compiler error for chromeOS) Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/log/trace_net_log_observer_unittest.cc ('k') | net/log/write_to_file_net_log_observer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/log/write_to_file_net_log_observer.h
diff --git a/net/log/net_log_logger.h b/net/log/write_to_file_net_log_observer.h
similarity index 80%
rename from net/log/net_log_logger.h
rename to net/log/write_to_file_net_log_observer.h
index 111d8ddd60a120c583c6a49ef27a1d6322f1b06c..bd147e3990c6086d38ea6ab1e0a813b1be45381a 100644
--- a/net/log/net_log_logger.h
+++ b/net/log/write_to_file_net_log_observer.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_LOG_NET_LOG_LOGGER_H_
-#define NET_LOG_NET_LOG_LOGGER_H_
+#ifndef WRITE_TO_FILE_NET_LOG_OBSERVER_H_
+#define WRITE_TO_FILE_NET_LOG_OBSERVER_H_
#include <stdio.h>
@@ -22,14 +22,14 @@ namespace net {
class URLRequestContext;
// NetLogLogger watches the NetLog event stream, and sends all entries to
// a file specified on creation.
//
// The text file will contain a single JSON object.
-class NET_EXPORT NetLogLogger : public NetLog::ThreadSafeObserver {
+class NET_EXPORT WriteToFileNetLogObserver : public NetLog::ThreadSafeObserver {
public:
- NetLogLogger();
- ~NetLogLogger() override;
+ WriteToFileNetLogObserver();
+ ~WriteToFileNetLogObserver() override;
// Sets the log level to log at. Must be called before StartObserving.
void set_log_level(NetLog::LogLevel log_level);
@@ -52,7 +52,7 @@ class NET_EXPORT NetLogLogger : public NetLog::ThreadSafeObserver {
net::URLRequestContext* url_request_context);
// Stops observing net_log(). Must already be watching. Must be called
// before destruction of the NetLogLogger and the NetLog.
//
// |url_request_context| is an optional argument used to added additional
// network stack state to the log. If the context is non-NULL, this must be
@@ -71,9 +71,9 @@ class NET_EXPORT NetLogLogger : public NetLog::ThreadSafeObserver {
// True if OnAddEntry() has been called at least once.
bool added_events_;
- DISALLOW_COPY_AND_ASSIGN(NetLogLogger);
+ DISALLOW_COPY_AND_ASSIGN(WriteToFileNetLogObserver);
};
} // namespace net
-#endif // NET_LOG_NET_LOG_LOGGER_H_
+#endif // WRITE_TO_FILE_NET_LOG_OBSERVER_H_
« no previous file with comments | « net/log/trace_net_log_observer_unittest.cc ('k') | net/log/write_to_file_net_log_observer.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -22,14 +22,14 @@ namespace net {
class URLRequestContext;
-// NetLogLogger watches the NetLog event stream, and sends all entries to
-// a file specified on creation.
+// WriteToFileNetLogObserver watches the NetLog event stream, and sends all
+// entries to a file specified on creation.
//
// The text file will contain a single JSON object.
@@ -52,7 +52,7 @@ class NET_EXPORT NetLogLogger : public NetLog::ThreadSafeObserver {
net::URLRequestContext* url_request_context);
// Stops observing net_log(). Must already be watching. Must be called
- // before destruction of the NetLogLogger and the NetLog.
+ // before destruction of the WriteToFileNetLogObserver and the NetLog.
//
// |url_request_context| is an optional argument used to added additional
This is Rietveld 408576698